@@ -25,6 +25,7 @@ __all__ = (
 import ibus
 import gobject
 import os
+import signal
 import os.path as path
 from ibus import keysyms
 from ibus import modifier
@@ -918,13 +919,14 @@ class PinYinEngine(ibus.EngineBase):
         if PinYinEngine.__setup_pid != 0:
             pid, state = os.waitpid(PinYinEngine.__setup_pid, os.P_NOWAIT)
             if pid != PinYinEngine.__setup_pid:
+                os.kill(PinYinEngine.__setup_pid, signal.SIGUSR1)
                 return
             PinYinEngine.__setup_pid = 0
         setup_cmd = path.join(LIBEXECDIR, "ibus-setup-pinyin")
         PinYinEngine.__setup_pid = os.spawnl(os.P_NOWAIT, setup_cmd, "ibus-setup-pinyin")
 
 
-    def process_key_event(self, keyval, state):
+    def process_key_event(self, keyval, keycode, state):
         key = KeyEvent(keyval, state & modifier.RELEASE_MASK == 0, state)
         result = self.__internal_process_key_event(key)
         self.__update()
@@ -986,6 +988,10 @@ class PinYinEngine(ibus.EngineBase):
             self.update_lookup_table(self.__lookup_table, True, True)
         return True
 
+    def candidate_clicked(self, index, button, state):
+        if button == 1:
+            self.process_key_event(keysyms._1 + index, state)
+
     def reset(self):
         self.__temp_english_mode = False
         self.__i_mode = False
